
from django.conf import settings
from django.shortcuts import get_object_or_404, render
from django.contrib.auth.views import redirect_to_login
from django.http import Http404, HttpResponsePermanentRedirect
from django.contrib.sites.models import Site

from flatpages.models import FlatPage


DEFAULT_TEMPLATE = 'flatpages/default.html'


def flatpage(request, url):

    if not url.startswith('/'):
        url = '/' + url

    host = request.META.get('HTTP_HOST')

    site_id = Site.objects.get(domain=host).id

    try:
        f = get_object_or_404(FlatPage, url=url, site_id=site_id)
    except Http404:
        if not url.endswith('/') and settings.APPEND_SLASH:
            url += '/'
            f = get_object_or_404(FlatPage, url=url, site_id=site_id)
            return HttpResponsePermanentRedirect('%s/' % request.path)
        else:
            raise

    if f.registration_required and not request.user.is_authenticated():
        return redirect_to_login(request.path)

    template_name = f.template_name or DEFAULT_TEMPLATE

    return render(request, template_name, {'flatpage': f})



# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-10-23 14:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('flatpages', '0002_model_translation'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='flatpage',
            options={'ordering': ['url'], 'verbose_name': 'flat page', 'verbose_name_plural': 'flat pages'},
        ),
        migrations.AddField(
            model_name='flatpage',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.Site', verbose_name='Site'),
        ),
    ]




import flatpages.translation

from django.apps import apps
from django.db import models
from django.contrib import admin

from modeltranslation.admin import TranslationAdmin

from flatpages.forms import FlatpageForm
from flatpages.models import FlatPage


class FlatPageAdmin(TranslationAdmin):

    form = FlatpageForm

    list_display = ['url', 'title', 'site']

    list_filter = ['site', 'registration_required']

    search_fields = ['url', 'title']

    def __init__(self, *args, **kwargs):

        if apps.is_installed('ckeditor_uploader'):
            from ckeditor_uploader.widgets import CKEditorUploadingWidget
            self.formfield_overrides = {
                models.TextField: {'widget': CKEditorUploadingWidget}
            }

        elif apps.is_installed('ckeditor'):
            from ckeditor.widgets import CKEditorWidget
            self.formfield_overrides = {
                models.TextField: {'widget': CKEditorWidget}
            }

        super(FlatPageAdmin, self).__init__(*args, **kwargs)


admin.site.register(FlatPage, FlatPageAdmin)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-01-16 15:26
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


def generate_operations():

    operations = []

    for code, name in settings.LANGUAGES:

        operations += [
            migrations.AddField(
                model_name='flatpage',
                name='title_%s' % code,
                field=models.CharField(max_length=200, null=True,
                                       verbose_name='title'),
            ),
            migrations.AddField(
                model_name='flatpage',
                name='content_%s' % code,
                field=models.TextField(blank=True, null=True,
                                       verbose_name='content'),
            ),
            migrations.AddField(
                model_name='flatpage',
                name='meta_k_%s' % code,
                field=models.CharField(max_length=200, null=True,
                                       verbose_name='keywords'),
            ),
            migrations.AddField(
                model_name='flatpage',
                name='meta_d_%s' % code,
                field=models.CharField(max_length=200, null=True,
                                       verbose_name='description'),
            )
        ]

    return operations


class Migration(migrations.Migration):

    dependencies = [
        ('flatpages', '0001_initial'),
    ]

    operations = generate_operations()




from modeltranslation.translator import register, TranslationOptions

from flatpages.models import FlatPage


@register(FlatPage)
class FlatPageTranslationOptions(TranslationOptions):

    fields = ('title', 'meta_k', 'meta_d', 'content', )
